@@ -12,7 +12,6 @@ More information is available on the Adobe website:
 """
 
 import sys
-import re
 import os
 import os.path
 import gzip
@@ -20,9 +19,9 @@ import pickle as pickle
 from . import cmap
 import struct
 from .psparser import PSStackParser
-from .psparser import PSException, PSSyntaxError, PSTypeError, PSEOF
-from .psparser import PSLiteral, PSKeyword
-from .psparser import literal_name, keyword_name
+from .psparser import PSSyntaxError, PSEOF
+from .psparser import PSLiteral
+from .psparser import literal_name
 from .encodingdb import name2unicode
 from .utils import choplist, nunpack
 
@@ -30,15 +29,12 @@ from .utils import choplist, nunpack
 class CMapError(Exception): pass
 
 
-##  CMap
-##
-class CMap(object):
+class CMap:
 
     debug = 0
 
     def __init__(self, code2cid=None):
         self.code2cid = code2cid or {}
-        return
 
     def is_vertical(self):
         return False
@@ -54,7 +50,6 @@ class CMap(object):
                 else:
                     dst[k] = v
         copy(self.code2cid, cmap.code2cid)
-        return
 
     def decode(self, code):
         if self.debug:
@@ -69,7 +64,6 @@ class CMap(object):
                     d = self.code2cid
             else:
                 d = self.code2cid
-        return
 
     def dump(self, out=sys.stdout, code2cid=None, code=None):
         if code2cid is None:
@@ -81,16 +75,12 @@ class CMap(object):
                 out.write('code %r = cid %d\n' % (c,v))
             else:
                 self.dump(out=out, code2cid=v, code=c)
-        return
     
 
-##  IdentityCMap
-##
-class IdentityCMap(object):
+class IdentityCMap:
 
     def __init__(self, vertical):
         self.vertical = vertical
-        return
 
     def is_vertical(self):
         return self.vertical
@@ -106,15 +96,12 @@ class IdentityCMap(object):
         
             
 
-##  UnicodeMap
-##
-class UnicodeMap(object):
+class UnicodeMap:
 
     debug = 0
 
     def __init__(self, cid2unichr=None):
         self.cid2unichr = cid2unichr or {}
-        return
 
     def get_unichr(self, cid):
         if self.debug:
@@ -124,17 +111,13 @@ class UnicodeMap(object):
     def dump(self, out=sys.stdout):
         for (k,v) in sorted(self.cid2unichr.items()):
             out.write('cid %d = unicode %r\n' % (k,v))
-        return
 
 
-##  FileCMap
-##
 class FileCMap(CMap):
 
     def __init__(self):
         CMap.__init__(self)
         self.attrs = {}
-        return
 
     def __repr__(self):
         return '<CMap: %s>' % self.attrs.get('CMapName')
@@ -144,7 +127,6 @@ class FileCMap(CMap):
 
     def set_attr(self, k, v):
         self.attrs[k] = v
-        return
 
     def add_code2cid(self, code, cid):
         assert isinstance(code, str) and isinstance(cid, int)
@@ -159,24 +141,19 @@ class FileCMap(CMap):
                 d =t
         c = ord(code[-1])
         d[c] = cid
-        return
 
 
-##  FileUnicodeMap
-##
 class FileUnicodeMap(UnicodeMap):
     
     def __init__(self):
         UnicodeMap.__init__(self)
         self.attrs = {}
-        return
 
     def __repr__(self):
         return '<UnicodeMap: %s>' % self.attrs.get('CMapName')
 
     def set_attr(self, k, v):
         self.attrs[k] = v
-        return
 
     def add_cid2unichr(self, cid, code):
         assert isinstance(cid, int)
@@ -186,22 +163,21 @@ class FileUnicodeMap(UnicodeMap):
         elif isinstance(code, bytes):
             # Interpret as UTF-16BE.
             self.cid2unichr[cid] = code.decode('UTF-16BE', 'ignore')
+        elif isinstance(code, str):
+            # We sometimes get nullchars in there
+            self.cid2unichr[cid] = code.replace('\0', '')
         elif isinstance(code, int):
             self.cid2unichr[cid] = chr(code)
         else:
-            raise TypeError(code)
-        return
+            raise TypeError(repr(code))
 
 
-##  PyCMap
-##
 class PyCMap(CMap):
 
     def __init__(self, name, module):
         CMap.__init__(self, module.CODE2CID)
         self.name = name
         self._is_vertical = module.IS_VERTICAL
-        return
 
     def __repr__(self):
         return '<PyCMap: %s>' % (self.name)
@@ -210,8 +186,6 @@ class PyCMap(CMap):
         return self._is_vertical
     
 
-##  PyUnicodeMap
-##
 class PyUnicodeMap(UnicodeMap):
     
     def __init__(self, name, module, vertical):
@@ -221,15 +195,12 @@ class PyUnicodeMap(UnicodeMap):
             cid2unichr = module.CID2UNICHR_H
         UnicodeMap.__init__(self, cid2unichr)
         self.name = name
-        return
 
     def __repr__(self):
         return '<PyUnicodeMap: %s>' % (self.name)
 
 
-##  CMapDB
-##
-class CMapDB(object):
+class CMapDB:
 
     debug = 0
     _cmap_cache = {}
@@ -279,22 +250,18 @@ class CMapDB(object):
         return umaps[vertical]
 
 
-##  CMapParser
-##
 class CMapParser(PSStackParser):
 
     def __init__(self, cmap, fp):
         PSStackParser.__init__(self, fp)
         self.cmap = cmap
         self._in_cmap = False
-        return
 
     def run(self):
         try:
             self.nextobject()
         except PSEOF:
             pass
-        return
 
     def do_keyword(self, pos, token):
         name = token.name
@@ -305,8 +272,9 @@ class CMapParser(PSStackParser):
         elif name == 'endcmap':
             self._in_cmap = False
             return
-        if not self._in_cmap: return
-        #
+        if not self._in_cmap:
+            return
+        
         if name == 'def':
             try:
                 ((_,k),(_,v)) = self.pop(2)
@@ -371,7 +339,9 @@ class CMapParser(PSStackParser):
             objs = [ obj for (_,obj) in self.popall() ]
             # These objects were hex numbers and have been parsed into a string. But what we want
             # are bytes. Convert them.
-            objs = [o.encode('ascii') for o in objs]
+            # Oh wait, it seems that sometimes we have bytes...
+            tobytes = lambda o: (o.encode('ascii') if isinstance(o, str) else o)
+            objs = [tobytes(o) for o in objs]
             for (s,e,code) in choplist(3, objs):
                 if (not isinstance(s, bytes) or not isinstance(e, bytes) or
                     len(s) != len(e)): continue
@@ -409,18 +379,17 @@ class CMapParser(PSStackParser):
             return
 
         self.push((pos, token))
-        return
 
 # test
 def main(argv):
     args = argv[1:]
     for fname in args:
-        fp = file(fname, 'rb')
+        fp = open(fname, 'rb')
         cmap = FileUnicodeMap()
         #cmap = FileCMap()
         CMapParser(cmap, fp).run()
         fp.close()
         cmap.dump()
-    return
 
-if __name__ == '__main__': sys.exit(main(sys.argv))
+if __name__ == '__main__':
+    sys.exit(main(sys.argv))
