@@ -1,11 +1,7 @@
-#!/usr/bin/env python3
-
 import sys
 import io
 
-##  LZWDecoder
-##
-class LZWDecoder(object):
+class LZWDecoder:
 
     debug = 0
 
@@ -16,7 +12,6 @@ class LZWDecoder(object):
         self.nbits = 9
         self.table = None
         self.prevbuf = None
-        return
 
     def readbits(self, bits):
         v = 0
@@ -82,7 +77,6 @@ class LZWDecoder(object):
             if self.debug:
                 print(('nbits=%d, code=%d, output=%r, table=%r' %
                                      (self.nbits, code, x, self.table[258:])), file=sys.stderr)
-        return
 
 # lzwdecode
 def lzwdecode(data):
