@@ -1,19 +1,11 @@
-#!/usr/bin/env python3
-
 import sys
 import io
 import re
 import struct
 import hashlib as md5
-from .psparser import PSStackParser
-from .psparser import PSSyntaxError, PSEOF
-from .psparser import literal_name
-from .psparser import LIT, KWD, STRICT
-from .pdftypes import PDFException, PDFTypeError, PDFNotImplementedError
-from .pdftypes import PDFStream, PDFObjRef
-from .pdftypes import resolve1, decipher_all
-from .pdftypes import int_value, float_value, num_value
-from .pdftypes import str_value, list_value, dict_value, stream_value
+from .psparser import PSStackParser, PSSyntaxError, PSEOF, literal_name, LIT, KWD, STRICT
+from .pdftypes import (PDFException, PDFTypeError, PDFNotImplementedError, PDFStream, PDFObjRef,
+    resolve1, decipher_all, int_value, str_value, list_value, dict_value, stream_value)
 from .arcfour import Arcfour
 from .utils import choplist, nunpack
 from .utils import decode_text, ObjIdRange
@@ -36,9 +28,7 @@ LITERAL_PAGES = LIT('Pages')
 LITERAL_CATALOG = LIT('Catalog')
 
 
-##  XRefs
-##
-class PDFBaseXRef(object):
+class PDFBaseXRef:
 
     def get_trailer(self):
         raise NotImplementedError
@@ -50,14 +40,11 @@ class PDFBaseXRef(object):
         raise KeyError(objid)
 
 
-##  PDFXRef
-##
 class PDFXRef(PDFBaseXRef):
     
     def __init__(self):
         self.offsets = {}
         self.trailer = {}
-        return
 
     def load(self, parser, debug=0):
         while 1:
@@ -92,7 +79,6 @@ class PDFXRef(PDFBaseXRef):
         if 1 <= debug:
             print('xref objects:', self.offsets, file=sys.stderr)
         self.load_trailer(parser)
-        return
 
     KEYWORD_TRAILER = KWD('trailer')
     def load_trailer(self, parser):
@@ -106,7 +92,6 @@ class PDFXRef(PDFBaseXRef):
                 raise PDFNoValidXRef('Unexpected EOF - file corrupted')
             (_,dic) = x[0]
         self.trailer.update(dict_value(dic))
-        return
 
     PDFOBJ_CUE = re.compile(r'^(\d+)\s+(\d+)\s+obj\b')
     def load_fallback(self, parser, debug=0):
@@ -126,7 +111,6 @@ class PDFXRef(PDFBaseXRef):
             if not m: continue
             (objid, genno) = m.groups()
             self.offsets[int(objid)] = (0, pos)
-        return
 
     def get_trailer(self):
         return self.trailer
@@ -142,8 +126,6 @@ class PDFXRef(PDFBaseXRef):
         return (None, pos)
 
 
-##  PDFXRefStream
-##
 class PDFXRefStream(PDFBaseXRef):
 
     def __init__(self):
@@ -151,7 +133,6 @@ class PDFXRefStream(PDFBaseXRef):
         self.entlen = None
         self.fl1 = self.fl2 = self.fl3 = None
         self.objid_ranges = []
-        return
 
     def __repr__(self):
         return '<PDFXRefStream: fields=%d,%d,%d>' % (self.fl1, self.fl2, self.fl3)
@@ -177,7 +158,6 @@ class PDFXRefStream(PDFBaseXRef):
             print(('xref stream: objid=%s, fields=%d,%d,%d' %
                              (', '.join(map(repr, self.objid_ranges)),
                               self.fl1, self.fl2, self.fl3)), file=sys.stderr)
-        return
 
     def get_trailer(self):
         return self.trailer
@@ -186,7 +166,6 @@ class PDFXRefStream(PDFBaseXRef):
         for objid_range in self.objid_ranges:
             for x in range(objid_range.get_start_id(), objid_range.get_end_id()+1):
                 yield x
-        return
 
     def get_pos(self, objid):
         offset = 0
@@ -214,9 +193,7 @@ class PDFXRefStream(PDFBaseXRef):
         raise KeyError(objid)
 
 
-##  PDFPage
-##
-class PDFPage(object):
+class PDFPage:
 
     """An object that holds the information about a page.
 
@@ -265,15 +242,12 @@ class PDFPage(object):
         if not isinstance(contents, list):
             contents = [ contents ]
         self.contents = contents
-        return
 
     def __repr__(self):
         return '<PDFPage: Resources=%r, MediaBox=%r>' % (self.resources, self.mediabox)
 
 
-##  PDFDocument
-##
-class PDFDocument(object):
+class PDFDocument:
 
     """PDFDocument object represents a PDF document.
 
@@ -301,11 +275,11 @@ class PDFDocument(object):
         self._parser = None
         self._cached_objs = {}
         self._parsed_objs = {}
-        return
 
     def set_parser(self, parser):
         "Set the document to use a given PDFParser object."
-        if self._parser: return
+        if self._parser:
+            return
         self._parser = parser
         # Retrieve the information of each header that was appended
         # (maybe multiple times) at the end of the document.
@@ -329,7 +303,6 @@ class PDFDocument(object):
         if self.catalog.get('Type') is not LITERAL_CATALOG:
             if STRICT:
                 raise PDFSyntaxError('Catalog not found!')
-        return
 
     # initialize(password='')
     #   Perform the initialization with a given password.
@@ -392,7 +365,6 @@ class PDFDocument(object):
             raise PDFPasswordIncorrect
         self.decrypt_key = key
         self.decipher = self.decrypt_rc4  # XXX may be AES
-        return
 
     def decrypt_rc4(self, objid, genno, data):
         key = self.decrypt_key + struct.pack('<L',objid)[:3]+struct.pack('<L',genno)[:2]
@@ -510,10 +482,10 @@ class PDFDocument(object):
                 if 1 <= self.debug:
                     print('Page: %r' % tree, file=sys.stderr)
                 yield (objid, tree)
-        if 'Pages' not in self.catalog: return
+        if 'Pages' not in self.catalog:
+            return
         for (pageid,tree) in search(self.catalog['Pages'], self.catalog):
             yield PDFPage(self, pageid, tree)
-        return
 
     def get_outlines(self):
         if 'Outlines' not in self.catalog:
@@ -533,7 +505,6 @@ class PDFDocument(object):
             if 'Next' in entry:
                 for x in search(entry['Next'], level):
                     yield x
-            return
         return search(self.catalog['Outlines'], 0)
 
     def lookup_name(self, cat, key):
@@ -573,8 +544,6 @@ class PDFDocument(object):
         return obj
 
 
-##  PDFParser
-##
 class PDFParser(PSStackParser):
 
     """
@@ -596,12 +565,10 @@ class PDFParser(PSStackParser):
         PSStackParser.__init__(self, fp)
         self.doc = None
         self.fallback = False
-        return
 
     def set_document(self, doc):
         """Associates the parser with a PDFDocument object."""
         self.doc = doc
-        return
 
     KEYWORD_R = KWD('R')
     KEYWORD_NULL = KWD('null')
@@ -679,7 +646,6 @@ class PDFParser(PSStackParser):
             # others
             self.push((pos, token))
         
-        return
 
     def find_xref(self):
         """Internal function used to locate the first XRef."""
@@ -731,7 +697,6 @@ class PDFParser(PSStackParser):
             # find previous xref
             pos = int_value(trailer['Prev'])
             self.read_xref_from(pos, xrefs)
-        return
 
     # read xref tables and trailers
     def read_xref(self):
@@ -751,8 +716,6 @@ class PDFParser(PSStackParser):
         return xrefs
 
 
-##  PDFStreamParser
-##
 class PDFStreamParser(PDFParser):
 
     """
@@ -765,11 +728,9 @@ class PDFStreamParser(PDFParser):
 
     def __init__(self, data):
         PDFParser.__init__(self, io.StringIO(data))
-        return
 
     def flush(self):
         self.add_results(*self.popall())
-        return
 
     def do_keyword(self, pos, token):
         if token is self.KEYWORD_R:
@@ -784,4 +745,3 @@ class PDFStreamParser(PDFParser):
             return
         # others
         self.push((pos, token))
-        return
