@@ -1,4 +1,3 @@
-#!/usr/bin/env python3
 import sys
 import re
 from .utils import choplist
@@ -18,17 +17,11 @@ class PSValueError(PSException): pass
 ##  Basic PostScript Types
 ##
 
-##  PSObject
-##
-class PSObject(object):
+class PSObject:
 
     """Base class for all PS or PDF-related data types."""
 
-    pass
 
-
-##  PSLiteral
-##
 class PSLiteral(PSObject):
 
     """A class that represents a PostScript literal.
@@ -44,14 +37,11 @@ class PSLiteral(PSObject):
 
     def __init__(self, name):
         self.name = name
-        return
 
     def __repr__(self):
         return '/%s' % self.name
 
 
-##  PSKeyword
-##
 class PSKeyword(PSObject):
 
     """A class that represents a PostScript keyword.
@@ -66,15 +56,12 @@ class PSKeyword(PSObject):
 
     def __init__(self, name):
         self.name = name
-        return
 
     def __repr__(self):
         return self.name
 
 
-##  PSSymbolTable
-##
-class PSSymbolTable(object):
+class PSSymbolTable:
 
     """A utility class for storing PSLiteral/PSKeyword objects.
 
@@ -84,7 +71,6 @@ class PSSymbolTable(object):
     def __init__(self, klass):
         self.dict = {}
         self.klass = klass
-        return
 
     def intern(self, name):
         if name in self.dict:
@@ -123,8 +109,6 @@ def keyword_name(x):
     return x.name
 
 
-##  PSBaseParser
-##
 ##  About PSParser, bytes and strings and all that
 ##  
 ##  Most of the contents (well, maybe not in size, but in "parsing effort") of a PDF file is text,
@@ -147,7 +131,7 @@ END_KEYWORD = re.compile(r'[#/%\[\]()<>{}\s]')
 END_STRING = re.compile(r'[()\134]')
 OCT_STRING = re.compile(r'[0-7]')
 ESC_STRING = { 'b':8, 't':9, 'n':10, 'f':12, 'r':13, '(':40, ')':41, '\\':92 }
-class PSBaseParser(object):
+class PSBaseParser:
 
     """Most basic PostScript parser that performs only tokenization.
     """
@@ -158,17 +142,15 @@ class PSBaseParser(object):
     def __init__(self, fp):
         self.fp = fp
         self.seek(0)
-        return
 
     def __repr__(self):
         return '<%s: %r, bufpos=%d>' % (self.__class__.__name__, self.fp, self.bufpos)
 
     def flush(self):
-        return
+        pass
 
     def close(self):
         self.flush()
-        return
 
     def tell(self):
         return self.bufpos+self.charpos
@@ -180,7 +162,6 @@ class PSBaseParser(object):
         self.fp.seek(pos)
         print('poll(%d): %r' % (pos, self.fp.read(n)), file=sys.stderr)
         self.fp.seek(pos0)
-        return
 
     def seek(self, pos):
         """Seeks the parser to the given position.
@@ -197,10 +178,10 @@ class PSBaseParser(object):
         self._curtoken = ''
         self._curtokenpos = 0
         self._tokens = []
-        return
 
     def fillbuf(self):
-        if self.charpos < len(self.buf): return
+        if self.charpos < len(self.buf):
+            return
         # fetch next chunk.
         self.bufpos = self.fp.tell()
         read_bytes = self.fp.read(self.BUFSIZ)
@@ -211,7 +192,6 @@ class PSBaseParser(object):
         if not self.buf:
             raise PSEOF('Unexpected EOF')
         self.charpos = 0
-        return
 
     def nextline(self):
         """Fetches a next line that ends either with \\r or \\n.
@@ -266,7 +246,6 @@ class PSBaseParser(object):
                 yield s[n:]+buf
                 s = s[:n]
                 buf = ''
-        return
 
     def _parse_main(self, s, i):
         m = NONSPC.search(s, i)
@@ -314,7 +293,6 @@ class PSBaseParser(object):
 
     def _add_token(self, obj):
         self._tokens.append((self._curtokenpos, obj))
-        return
 
     def _parse_comment(self, s, i):
         m = EOL.search(s, i)
@@ -492,30 +470,24 @@ class PSBaseParser(object):
         return token
 
 
-##  PSStackParser
-##
 class PSStackParser(PSBaseParser):
 
     def __init__(self, fp):
         PSBaseParser.__init__(self, fp)
         self.reset()
-        return
 
     def reset(self):
         self.context = []
         self.curtype = None
         self.curstack = []
         self.results = []
-        return
 
     def seek(self, pos):
         PSBaseParser.seek(self, pos)
         self.reset()
-        return
 
     def push(self, *objs):
         self.curstack.extend(objs)
-        return
     
     def pop(self, n):
         objs = self.curstack[-n:]
@@ -531,14 +503,12 @@ class PSStackParser(PSBaseParser):
         if 2 <= self.debug:
             print('add_results: %r' % (objs,), file=sys.stderr)
         self.results.extend(objs)
-        return
 
     def start_type(self, pos, type):
         self.context.append((pos, self.curtype, self.curstack))
         (self.curtype, self.curstack) = (type, [])
         if 2 <= self.debug:
             print('start_type: pos=%r, type=%r' % (pos, type), file=sys.stderr)
-        return
     
     def end_type(self, type):
         if self.curtype != type:
@@ -550,7 +520,7 @@ class PSStackParser(PSBaseParser):
         return (pos, objs)
 
     def do_keyword(self, pos, token):
-        return
+        pass
 
     def nextobject(self):
         """Yields a list of objects.
@@ -561,12 +531,7 @@ class PSStackParser(PSBaseParser):
         while not self.results:
             (pos, token) = self.nexttoken()
             #print (pos,token), (self.curtype, self.curstack)
-            if (isinstance(token, int) or
-                isinstance(token, float) or
-                isinstance(token, bool) or
-                isinstance(token, str) or
-                isinstance(token, bytes) or
-                isinstance(token, PSLiteral)):
+            if isinstance(token, (int, float, bool, str, bytes, PSLiteral)):
                 # normal token
                 self.push((pos, token))
             elif token == KEYWORD_ARRAY_BEGIN:
