@@ -1,7 +1,3 @@
-#!/usr/bin/env python3
-"""
-Miscellaneous Routines.
-"""
 import struct
 from sys import maxsize as INF
 
@@ -96,13 +92,6 @@ def uniq(objs):
         if obj in done: continue
         done.add(obj)
         yield obj
-    return
-
-# csort
-def csort(objs, key=lambda x:x):
-    """Order-preserving sorting function."""
-    idxs = dict( (obj,i) for (i,obj) in enumerate(objs) )
-    return sorted(objs, key=lambda obj: (key(obj), idxs[obj]))
 
 # fsplit
 def fsplit(pred, objs):
@@ -152,22 +141,23 @@ def choplist(n, seq):
         if len(r) == n:
             yield tuple(r)
             r = []
-    return
 
 # nunpack
-def nunpack(s, default=0):
+def nunpack(b, default=0):
     """Unpacks 1 to 4 byte integers (big endian)."""
-    l = len(s)
+    if isinstance(b, str):
+        b = b.encode('latin-1')
+    l = len(b)
     if not l:
         return default
     elif l == 1:
-        return ord(s)
+        return b[0]
     elif l == 2:
-        return struct.unpack(b'>H', s)[0]
+        return struct.unpack(b'>H', b)[0]
     elif l == 3:
-        return struct.unpack(b'>L', b'\x00'+s)[0]
+        return struct.unpack(b'>L', b'\x00'+b)[0]
     elif l == 4:
-        return struct.unpack(b'>L', s)[0]
+        return struct.unpack(b'>L', b)[0]
     else:
         raise TypeError('invalid length: %d' % l)
 
@@ -230,16 +220,13 @@ def matrix2str(matrix):
     return '[%.2f,%.2f,%.2f,%.2f, (%.2f,%.2f)]' % (a,b,c,d,e,f)
 
 
-##  ObjIdRange
-##
-class ObjIdRange(object):
+class ObjIdRange:
 
     "A utility class to represent a range of object IDs."
     
     def __init__(self, start, nobjs):
         self.start = start
         self.nobjs = nobjs
-        return
 
     def __repr__(self):
         return '<ObjIdRange: %d-%d>' % (self.get_start_id(), self.get_end_id())
@@ -261,7 +248,7 @@ class ObjIdRange(object):
 ##  It maintains two parallel lists of objects, each of
 ##  which is sorted by its x or y coordinate.
 ##
-class Plane(object):
+class Plane:
 
     def __init__(self, objs=None, gridsize=50):
         self._objs = []
@@ -270,7 +257,6 @@ class Plane(object):
         if objs is not None:
             for obj in objs:
                 self.add(obj)
-        return
 
     def __repr__(self):
         return ('<Plane objs=%r>' % list(self))
@@ -289,7 +275,6 @@ class Plane(object):
         for y in drange(y0, y1, self.gridsize):
             for x in drange(x0, x1, self.gridsize):
                 yield (x,y)
-        return
     
     # add(obj): place an object.
     def add(self, obj):
@@ -301,7 +286,6 @@ class Plane(object):
                 r = self._grid[k]
             r.append(obj)
         self._objs.append(obj)
-        return
 
     # remove(obj): displace an object.
     def remove(self, obj):
@@ -311,7 +295,6 @@ class Plane(object):
             except (KeyError, ValueError):
                 pass
         self._objs.remove(obj)
-        return
 
     # find(): finds objects that are in a certain area.
     def find(self, area):
@@ -325,7 +308,6 @@ class Plane(object):
                 if (obj.x1 <= x0 or x1 <= obj.x0 or
                     obj.y1 <= y0 or y1 <= obj.y0): continue
                 yield obj
-        return
 
 
 # create_bmp
